@@ -427,27 +427,6 @@ addEvent(window, "load", function() {
             generate.call(this, dom, wikitext);
         });
 
-        unit.add("!||, !=||", function() {
-            var dom = fragment(
-                element("p", "Paragraph"),
-                element("table", { "class": "wiki" },
-                    element("tbody",
-                        element("tr", element("td", "foo||bar!||||==||foobar")))),
-                element("p", "||||cell=||= =||||=cell|| Paragraph"));
-            generateFragment.call(this, dom, [
-                "Paragraph",
-                "||foo!||bar!!||||=!=||foobar",
-                "!||||cell!=||=",
-                "!=||||=cell!||",
-                "Paragraph" ].join("\n"));
-            generate.call(this, dom, [
-                "Paragraph",
-                "",
-                "|| foo!||bar!!||||=!=||foobar ||",
-                "",
-                "!||||cell!=||= !=||||=cell!|| Paragraph" ].join("\n"));
-        });
-
         unit.add("#ticket", function() {
             var dom = element("p",
                 a("ticket:1234", "#1234"),
@@ -509,12 +488,6 @@ addEvent(window, "load", function() {
                 " ",
                 a("rfc-2396.compatible://link", "RFC 2396"),
                 " ",
-                "21:09,",
-                element("u", "underline"),
-                ",abc123 !21:09,",
-                element("u", "underline"),
-                ",abc123",
-                " ",
                 a("foo:bar", "foo:bar"),
                 " begin",
                 a("foo:bar", "foo:bar"),
@@ -529,7 +502,6 @@ addEvent(window, "load", function() {
                 "link:'Foo Bar' link:'Foo Bar#baz'",
                 "svn+ssh://example.com/trunk [svn+ssh://example.com/trunk repository]",
                 "rfc-2396.compatible://link [rfc-2396.compatible://link RFC 2396]",
-                "21:09,__underline__,abc123 !21:09,__underline__,abc123",
                 "foo:bar begin[foo:bar foo:bar] [foo:bar foo:bar]end begin[wiki:WikiStart]end",
                 "!link:'Foo Bar#baz'" ].join(" "));
             generate.call(this, dom, [
@@ -538,7 +510,6 @@ addEvent(window, "load", function() {
                 "link:'Foo Bar' link:'Foo Bar#baz'",
                 "svn+ssh://example.com/trunk [svn+ssh://example.com/trunk repository]",
                 "rfc-2396.compatible://link [rfc-2396.compatible://link RFC 2396]",
-                "21:09,__underline__,abc123 !21:09,__underline__,abc123",
                 "foo:bar begin[foo:bar foo:bar] [foo:bar foo:bar]end begin[wiki:WikiStart]end",
                 "!link:'Foo Bar#baz'" ].join(" "));
         });
@@ -611,58 +582,12 @@ addEvent(window, "load", function() {
             generate.call(this, dom, wikitext);
         });
 
-        unit.add("<wiki:bracket links>", function() {
-            var dom = fragment(
-                element("p", "<", a("link:1"), ">"),
-                element("p", "Thing<", a("link:2 and (3)"), ">"),
-                element("p", "<link:1>"),
-                element("p", "Thing<link:2 and (3)>"));
-            var wikitext = [
-                "<link:1>",
-                "",
-                "Thing<link:2 and (3)>",
-                "",
-                "!<link:1>",
-                "",
-                "Thing!<link:2 and (3)>" ].join("\n");
-            generate.call(this, dom, wikitext);
-        });
-
-        unit.add("[=#anchor]", function() {
-            var dom = fragment(
-                element("p",
-                    "This is the ",
-                    element("span", { "class": "wikianchor", id: "init" }),
-                    " initialization routine: ..."),
-                element("p",
-                    "Look for ",
-                    element("span", { "class": "wikianchor", id : "extra" },
-                        element("i", "additional explanations")),
-                    " here."),
-                element("p",
-                    "これは",
-                    element("span", { "class": "wikianchor", id: "初期化" }),
-                    "初期化ルーチン: ..."),
-                element("p",
-                    element("span", { "class": "wikianchor", id : "追加" }, element("i", "追加説明")),
-                    "はここを見てください。"));
-            var wikitext = [
-                "This is the [=#init] initialization routine: ...",
-                "",
-                "Look for [=#extra ''additional explanations''] here.",
-                "",
-                "これは[=#初期化]初期化ルーチン: ...",
-                "",
-                "[=#追加 ''追加説明'']はここを見てください。" ].join("\n");
-            generate.call(this, dom, wikitext);
-        });
-
         unit.add("[[macro]]", function() {
             var dom = element("p",
                 "Line break ", element("br"), " another line", element("br"),
-                "last line [[bR]] ![[Br]] [[Macro]] ![[Macro]] [[Image?]] ![[Image?]] [[?]] ![[?]]");
-            generateFragment.call(this, dom, "Line break [[BR]] another line[[br]]last line ![[bR]] !![[Br]] [[Macro]] ![[Macro]] [[Image?]] ![[Image?]] [[?]] ![[?]]");
-            generate.call(this, dom, "Line break [[BR]] another line[[BR]]last line ![[bR]] !![[Br]] [[Macro]] ![[Macro]] [[Image?]] ![[Image?]] [[?]] ![[?]]");
+                "last line [[bR]] ![[Br]] [[Macro]] ![[Macro]]");
+            generateFragment.call(this, dom, "Line break [[BR]] another line[[br]]last line ![[bR]] !![[Br]] [[Macro]] ![[Macro]]");
+            generate.call(this, dom, "Line break [[BR]] another line[[BR]]last line ![[bR]] !![[Br]] [[Macro]] ![[Macro]]");
         });
 
         unit.add("WikiPageName", function() {
@@ -897,25 +822,6 @@ addEvent(window, "load", function() {
                 "====== Heading 6 ====== #anchor-6" ].join("\n"));
         });
 
-        unit.add("header 2", function() {
-            var dom = fragment(
-                element("h1", "Heading 1"),
-                element("h2", { id: "anchor-2" }, "Heading 2"),
-                element("h3", element("u", "Heading"), " ", element("i", "3")),
-                element("h4", { id: "アンカー-4" },
-                    "Heading 4 with ",
-                    a("wiki:WikiStart", "link")),
-                element("h5", "Heading 5"),
-                element("h6", { id: "anchor-6" }, "Heading 6"));
-            generateFragment.call(this, dom, [
-                "= Heading 1  ",
-                "== Heading 2    #anchor-2",
-                "=== __Heading__ ''3''    ",
-                "==== Heading 4 with [wiki:WikiStart link]      #アンカー-4",
-                "===== Heading 5      ",
-                "====== Heading 6        #anchor-6" ].join("\n"));
-        });
-
         unit.add("list", function() {
             var dom = fragment(
                 element("p", "Paragraph"),
@@ -1110,35 +1016,6 @@ addEvent(window, "load", function() {
                 " 3. Item 3" ].join("\n"));
         });
 
-        unit.add("list at beginning of line", function() {
-            var dom = fragment(
-                element("ul",
-                    element("li", "item 1"),
-                    element("li", "item 2"),
-                    element("ul", element("li", "sub 2.1"), element("li", "sub 2.2"))),
-                element("ol", { "class": "loweralpha" },
-                    element("li", "item A"), element("li", "item B")),
-                element("p", "Paragraph"));
-            generateFragment.call(this, dom, [
-                "- item 1",
-                "- item 2",
-                "  - sub 2.1",
-                "  - sub 2.2",
-                "a. item A",
-                "b. item B",
-                "Paragraph" ].join("\n"));
-            generate.call(this, dom, [
-                " * item 1",
-                " * item 2",
-                "   * sub 2.1",
-                "   * sub 2.2",
-                "",
-                " a. item A",
-                " a. item B",
-                "",
-                "Paragraph" ].join("\n"));
-        });
-
         unit.add("list + code block", function() {
             var dom = fragment(
                 element("p", "Paragraph"),
@@ -1311,118 +1188,6 @@ addEvent(window, "load", function() {
                 "Paragraph" ].join("\n"));
         });
 
-        unit.add("colspan", function() {
-            var dom = fragment(
-                element("p", "Paragraph"),
-                element("table", { "class": "wiki" },
-                    element("tbody",
-                        element("tr", element("td", "1.1"), element("td", "1.2", { colSpan: 2 })),
-                        element("tr", element("td", "2.1", { colSpan: 3 })),
-                        element("tr",
-                            element("td", "3.1"),
-                            element("td", element("u", "3.2")),
-                            element("td", element("tt", "3.3"))))),
-                element("p", "Paragraph"));
-            generateFragment.call(this, dom, [
-                "Paragraph",
-                "||1.1||||1.2",
-                "||||||2.1",
-                "||3.1||__3.2__||`3.3`",
-                "Paragraph" ].join("\n"));
-            generate.call(this, dom, [
-                "Paragraph",
-                "",
-                "|| 1.1 |||| 1.2 ||",
-                "|||||| 2.1 ||",
-                "|| 3.1 || __3.2__ || `3.3` ||",
-                "",
-                "Paragraph" ].join("\n"));
-        });
-
-        unit.add("table header", function() {
-            var dom = fragment(
-                element("p", "Paragraph"),
-                element("table", { "class": "wiki" },
-                    element("tbody",
-                        element("tr", element("th", "1.1"), element("td", "1.2", { colSpan: 2 })),
-                        element("tr", element("th", "2.1", { colSpan: 3 })),
-                        element("tr",
-                            element("td", "3.1"),
-                            element("th", element("u", "3.2")),
-                            element("td", element("tt", "3.3"))))),
-                element("p", "Paragraph"));
-            generateFragment.call(this, dom, [
-                "Paragraph",
-                "||=1.1=||||1.2",
-                "||||||=2.1=||",
-                "||3.1||=__3.2__=||`3.3`",
-                "Paragraph" ].join("\n"));
-            generate.call(this, dom, [
-                "Paragraph",
-                "",
-                "||= 1.1 =|||| 1.2 ||",
-                "||||||= 2.1 =||",
-                "|| 3.1 ||= __3.2__ =|| `3.3` ||",
-                "",
-                "Paragraph" ].join("\n"));
-        });
-
-        unit.add("table with alignment", function() {
-            var dom = fragment(
-                element("p", "Paragraph"),
-                element("table", { "class": "wiki" },
-                    element("tbody",
-                        element("tr", element("th", "1.1"),
-                        element("td", "1.2", { colSpan: 2, align: "right" })),
-                        element("tr", element("th", "2.1", { colSpan: 3, align: "left" })),
-                        element("tr",
-                            element("td", "3||1", { align: "right" }),
-                            element("th", element("u", "3.2")),
-                            element("td", element("tt", "3.3"), { align: "left" })),
-                        element("tr",
-                            element("th", "4.1", { align: "center" }),
-                            element("td", "4.2"),
-                            element("td", "4.3", { align: "center" })))),
-                element("p", "Paragraph"));
-            generateFragment.call(this, dom, [
-                "Paragraph",
-                "||=1.1=|||| 1.2",
-                "||||||=2.1 =||",
-                "|| 3!||1||= __3.2__ =||`3.3` ||",
-                "||=  4.1     =|| 4.2 ||    4.3    ||",
-                "Paragraph" ].join("\n"));
-            generate.call(this, dom, [
-                "Paragraph",
-                "",
-                "||= 1.1 =|||| 1.2||",
-                "||||||=2.1 =||",
-                "|| 3!||1||= __3.2__ =||`3.3` ||",
-                "||=  4.1  =|| 4.2 ||  4.3  ||",
-                "",
-                "Paragraph" ].join("\n"));
-        });
-
-        unit.add("table with row continuation", function() {
-            var dom = fragment(
-                element("p", "Paragraph"),
-                element("table", { "class": "wiki" },
-                    element("tbody",
-                        element("tr", element("td", "1.1"), element("td", "1.2"), element("td", "1.3")),
-                        element("tr", element("td", "2.1")),
-                        element("tr",
-                            element("td", "3.1"),
-                            element("td", element("u", "3.2")),
-                            element("td", element("tt", "3.3"))))),
-                element("p", "Paragraph"));
-            generateFragment.call(this, dom, [
-                "Paragraph",
-                "||1.1||1.2||    \\",
-                "||1.3",
-                "||2.1",
-                "||3.1||__3.2__||`3.3`||\\",
-                "Paragraph" ].join("\n"));
-        });
-
         unit.add("table + rule", function() {
             var dom = fragment(
                 element("table", { "class": "wiki" },
@@ -1612,7 +1377,7 @@ addEvent(window, "load", function() {
                 " def to_s( ):: dt",
                 "    dd",
                 "",
-                "|| cell[[BR]]1 ||= cell[[BR]]2 =||" ].join("\n"), wikitext);
+                "|| cell[[BR]]1 || cell[[BR]]2 ||" ].join("\n"), wikitext);
         });
 
         unit.add("escape newlines", function() {
